@@ -9,7 +9,7 @@ Cmd5::Cmd5()
 
 void Cmd5::init()
 {
-#ifdef USE_SSL
+#ifdef USE_OPENSSL
   MD5_Init(&m_context);
 #else
   MD5Init(&m_context);
@@ -18,7 +18,7 @@ void Cmd5::init()
 
 void Cmd5::getSum(char *buf)
 {
-#ifdef USE_SSL
+#ifdef USE_OPENSSL
   MD5_Final((unsigned char *)buf, &m_context);
 #else
   MD5Final((unsigned char *)buf, &m_context);
@@ -39,7 +39,7 @@ string Cmd5::getSum()
 
 void Cmd5::addData(const char *buf, size_t bytes)
 {
-#ifdef USE_SSL
+#ifdef USE_OPENSSL
   MD5_Update(&m_context, (const unsigned char *)buf, bytes);
 #else
   MD5Update(&m_context, (unsigned char *)buf, bytes);
