@@ -59,7 +59,9 @@ int main(int argc, char **argv)
   bool debugMultipleFiles = false;
   bool strip_domain = false;
 #ifdef USE_GNUTLS
+#if GNUTLS_VERSION_NUMBER <= 0x020b00
   gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+#endif
   gnutls_global_init();
   if(!gnutls_check_version(GNUTLS_VER))
   {
@@ -138,6 +140,7 @@ int main(int argc, char **argv)
   UserList ul(argv[optind + 1], true, strip_domain);
 
   struct sigaction sa;
+  memset(&sa, 0, sizeof(sa));
   sa.sa_sigaction = NULL;
   sa.sa_handler = SIG_IGN;
   sa.sa_flags = 0;
@@ -171,6 +174,9 @@ int main(int argc, char **argv)
 #endif
               , qmail_pop, imap, downloadPercent, deletePercent, debug);
 
-  return popper.doAllWork(connectionsPerMinute);
+  int rc = popper.doAllWork(connectionsPerMinute);
+  if(debug)
+    delete debug;
+  return rc;
 }
 
